---
title: PETsARD (/pəˈtɑrd/)
type: page
weight: 0
toc: false
---

<p style="text-align:center">
  隱私強化技術分析、研究與開發
</p>

<p align="center"><img src="/petsard/images/PETsARD-logo.png"></p>

## 探索

{{< cards >}}
{{< card link="docs" title="文件" icon="book-open" >}}
{{< card link="about" title="關於" icon="user" >}}
{{< /cards >}}